@@ -1,4 +1,4 @@
-# Copyright (c) 2013-2020 Philip Hane
+# Copyright (c) 2013-2024 Philip Hane
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 import sys
-from xml.dom.minidom import parseString
+from defusedxml.minidom import parseString
 from os import path
 import re
 import copy
@@ -61,26 +61,26 @@ log = logging.getLogger(__name__)
 IETF_RFC_REFERENCES = {
     # IPv4
     'RFC 1122, Section 3.2.1.3':
-    'http://tools.ietf.org/html/rfc1122#section-3.2.1.3',
-    'RFC 1918': 'http://tools.ietf.org/html/rfc1918',
-    'RFC 3927': 'http://tools.ietf.org/html/rfc3927',
-    'RFC 5736': 'http://tools.ietf.org/html/rfc5736',
-    'RFC 5737': 'http://tools.ietf.org/html/rfc5737',
-    'RFC 3068': 'http://tools.ietf.org/html/rfc3068',
-    'RFC 2544': 'http://tools.ietf.org/html/rfc2544',
-    'RFC 3171': 'http://tools.ietf.org/html/rfc3171',
-    'RFC 919, Section 7': 'http://tools.ietf.org/html/rfc919#section-7',
+    'https://tools.ietf.org/html/rfc1122#section-3.2.1.3',
+    'RFC 1918': 'https://tools.ietf.org/html/rfc1918',
+    'RFC 3927': 'https://tools.ietf.org/html/rfc3927',
+    'RFC 5736': 'https://tools.ietf.org/html/rfc5736',
+    'RFC 5737': 'https://tools.ietf.org/html/rfc5737',
+    'RFC 3068': 'https://tools.ietf.org/html/rfc3068',
+    'RFC 2544': 'https://tools.ietf.org/html/rfc2544',
+    'RFC 3171': 'https://tools.ietf.org/html/rfc3171',
+    'RFC 919, Section 7': 'https://tools.ietf.org/html/rfc919#section-7',
     # IPv6
-    'RFC 4291, Section 2.7': 'http://tools.ietf.org/html/rfc4291#section-2.7',
-    'RFC 4291': 'http://tools.ietf.org/html/rfc4291',
+    'RFC 4291, Section 2.7': 'https://tools.ietf.org/html/rfc4291#section-2.7',
+    'RFC 4291': 'https://tools.ietf.org/html/rfc4291',
     'RFC 4291, Section 2.5.2':
-    'http://tools.ietf.org/html/rfc4291#section-2.5.2',
+    'https://tools.ietf.org/html/rfc4291#section-2.5.2',
     'RFC 4291, Section 2.5.3':
-    'http://tools.ietf.org/html/rfc4291#section-2.5.3',
+    'https://tools.ietf.org/html/rfc4291#section-2.5.3',
     'RFC 4291, Section 2.5.6':
-    'http://tools.ietf.org/html/rfc4291#section-2.5.6',
+    'https://tools.ietf.org/html/rfc4291#section-2.5.6',
     'RFC 4291, Section 2.5.7':
-    'http://tools.ietf.org/html/rfc4291#section-2.5.7',
+    'https://tools.ietf.org/html/rfc4291#section-2.5.7',
     'RFC 4193': 'https://tools.ietf.org/html/rfc4193'
 }
 
@@ -352,12 +352,6 @@ def ipv4_is_defined(address):
 
         return results(True, 'Private-Use Networks', 'RFC 1918')
 
-    # New IANA Reserved
-    # TODO: Someone needs to find the RFC for this
-    elif query_ip in IPv4Network('198.97.38.0/24'):
-
-        return results(True, 'IANA Reserved', '')
-
     return results(False, '', '')
 
 
